==> hubzero-submit-server_2.5.1.orig.tar.gz: hubzero-submit-server-2.5.1/hubzero/submit/MySQLDatabase.py <==
# @package      hubzero-submit-server
# @file         MySQLDatabase.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import time
import MySQLdb

from hubzero.submit.LogMessage import logID as log

class MySQLDatabase:
   def __init__(self,
                mysqlHost="",
                mysqlUser="",
                mysqlPassword="",
                mysqlDB="",
                mysqlCA=""):
      self.mysqlHost     = mysqlHost
      self.mysqlUser     = mysqlUser
      self.mysqlPassword = mysqlPassword
      self.mysqlDB       = mysqlDB
      self.mysqlCA       = mysqlCA
      self.db            = None
      self.cursor        = None


   def connect(self,
               maximumAttempts=8):
      if self.db:
         connected = True
      else:
         if self.mysqlCA:
            sslSettings = {'ca':self.mysqlCA}
         else:
            sslSettings = {}

         connected = False
         attempts = 0
         delay = 1
         maxdelay = 256
         while attempts < maximumAttempts:
            try:
               attempts += 1
               self.db = MySQLdb.connect(host=self.mysqlHost,
                                         user=self.mysqlUser,
                                         passwd=self.mysqlPassword,
                                         ssl=sslSettings,
                                         db=self.mysqlDB)
               self.cursor = self.db.cursor()
               connected = True
               break
            except MySQLdb.Error, err:
               log("Exception in MySQLDatabase.connect: %d %s" % (err.args[0],err.args[1]))

            time.sleep(delay)
            if delay < maxdelay:
               delay = delay * 2

      return(connected)


   def disconnect(self):
      if self.db:
         self.db.close()
         self.db = None


   def select(self,
              sqlCommand):
      result = ()
      try:
         count = self.cursor.execute(sqlCommand)
         result = self.cursor.fetchall()
      except MySQLdb.MySQLError, (num, expl):
         log("%s.  SQL was: %s" % (expl,sqlCommand))
      except:
         log("Some other MySQL exception.")

      return(result)


   def update(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)


   def insert(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)


   def delete(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)

==> hubzero-submit-server_2.7.1.2.orig.tar.gz: hubzero-submit-server-2.7.1.2/hubzero/submit/MySQLDatabase.py <==
# @package      hubzero-submit-server
# @file         MySQLDatabase.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import time
import MySQLdb
import logging

from hubzero.submit.LogMessage import getLogIDMessage as getLogMessage

class MySQLDatabase:
   def __init__(self,
                mysqlHost="",
                mysqlUser="",
                mysqlPassword="",
                mysqlCA=""):
      self.logger        = logging.getLogger(__name__)
      self.mysqlHost     = mysqlHost
      self.mysqlUser     = mysqlUser
      self.mysqlPassword = mysqlPassword
      self.mysqlDB       = ""
      self.mysqlCA       = mysqlCA
      self.db            = None
      self.cursor        = None


   def connect(self,
               mysqlDB,
               maximumAttempts=8):
      connected = False
      if self.db and (mysqlDB == self.mysqlDB):
         connected = True
      elif self.db:
         self.disconnect()

      if not connected:
         if self.mysqlCA:
            sslSettings = {'ca':self.mysqlCA}
         else:
            sslSettings = {}

         attempts = 0
         delay = 1
         maxdelay = 256
         while attempts < maximumAttempts:
            try:
               attempts += 1
               self.db = MySQLdb.connect(host=self.mysqlHost,
                                         user=self.mysqlUser,
                                         passwd=self.mysqlPassword,
                                         ssl=sslSettings,
                                         db=mysqlDB)
               self.cursor = self.db.cursor()
               self.mysqlDB = mysqlDB
               connected = True
               break
            except MySQLdb.Error, err:
               self.logger.log(logging.ERROR,getLogMessage("Exception in MySQLDatabase.connect: %d %s" % (err.args[0],err.args[1])))

            time.sleep(delay)
            if delay < maxdelay:
               delay = delay * 2

      return(connected)


   def disconnect(self):
      if self.db:
         self.db.close()
         self.db      = None
         self.mysqlDB = ""


   def select(self,
              sqlCommand):
      result = ()
      try:
         count = self.cursor.execute(sqlCommand)
         result = self.cursor.fetchall()
      except MySQLdb.MySQLError, (num, expl):
         self.logger.log(logging.ERROR,getLogMessage("%s.  SQL was: %s" % (expl,sqlCommand)))
      except:
         self.logger.log(logging.ERROR,getLogMessage("Some other MySQL exception."))

      return(result)


   def update(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)


   def insert(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)


   def delete(self,
              sqlCommand):
      result = ""
      try:
         count = self.cursor.execute(sqlCommand)
      except MySQLdb.MySQLError, (num, expl):
         result = expl

      return(result)
